Module queue

Module queue 

The main queue of events in the simulator.

Structs

SimQueue
SimQueue represents the queue of events that are to be processed by the simulator. It is a wrapper around an EventQueue for the client and an EventQueue for the server. The goal is to never have to search through any of the queues, but to be able to directly access the next event that is to be processed with as little work as possible.