SimEvent

Struct SimEvent 

pub struct SimEvent {
    pub event: TriggerEvent,
    pub time: Instant,
    pub integration_delay: Duration,
    pub client: bool,
    pub contains_padding: bool,
    pub debug_note: Option<String>,
    /* private fields */
}
SimEvent represents an event in the simulator. It is used internally to represent events that are to be processed by the simulator (in SimQueue) and events that are produced by the simulator (the resulting trace).

Fields

event: TriggerEvent

the actual event

time: Instant

the time of the event taking place

integration_delay: Duration

the delay of the event due to integration

client: bool

flag to track if the event is from the client

contains_padding: bool

flag to track padding or normal packet

debug_note: Option<String>