pub struct SimEvent {
pub event: TriggerEvent,
pub time: Instant,
pub integration_delay: Duration,
pub client: bool,
pub contains_padding: bool,
pub debug_note: Option<String>,
/* private fields */
}Expand description
SimEvent represents an event in the simulator. It is used internally to represent events that are to be processed by the simulator (in SimQueue) and events that are produced by the simulator (the resulting trace).
Fields
event: TriggerEventthe actual event
time: Instantthe time of the event taking place
integration_delay: Durationthe delay of the event due to integration
client: boolflag to track if the event is from the client
contains_padding: boolflag to track padding or normal packet
debug_note: Option<String>Trait Implementations
impl Eq for SimEvent
Sourceimpl Ord for SimEvent
impl Ord for SimEvent
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for SimEvent
impl PartialOrd for SimEvent
impl StructuralPartialEq for SimEvent